RCCallSession class

Constructors

RCCallSession.fromJson(Map json)

Properties

caller ↔ RCCallUserProfile?
ZH
getter/setter pair
callId ↔ String
ZH
getter/setter pair
callType ↔ RCCallCallType
ZH
getter/setter pair
connectedTime ↔ int
ZH
getter/setter pair
endTime ↔ int
ZH
getter/setter pair
extra ↔ String?
ZH
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inviter ↔ RCCallUserProfile?
ZH
getter/setter pair
mediaType ↔ RCCallMediaType
ZH
getter/setter pair
mine ↔ RCCallUserProfile
ZH
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
ZH
getter/setter pair
startTime ↔ int
ZH
getter/setter pair
targetId ↔ String
ZH
getter/setter pair
users ↔ List<RCCallUserProfile>
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited