RCCallAndroidPushConfig class

Constructors

RCCallAndroidPushConfig.create({String? notificationId, String? channelIdForXiaoMi, String? channelIdForHuaWei, RCCallHuaWeiPushImportance? importanceForHuaWei, String? channelIdForOppo, RCCallVivoPushType? vivoPushType, String? collapseKeyForFCM, String? imageUrlForFCM})

Properties

channelIdForHuaWei ↔ String?
ZH
getter/setter pair
channelIdForOppo ↔ String?
ZH
getter/setter pair
channelIdForXiaoMi ↔ String?
ZH
getter/setter pair
collapseKeyForFCM ↔ String?
ZH
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUrlForFCM ↔ String?
ZH
getter/setter pair
importanceForHuaWei ↔ RCCallHuaWeiPushImportance?
ZH
getter/setter pair
notificationId ↔ String?
ZH
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vivoPushType ↔ RCCallVivoPushType?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited