RCCallAudioConfig class

ZH

android 平台独有配置项

EN

Android-only configuration

Constructors

RCCallAudioConfig.create({bool enableMicrophone = true, bool enableStereo = true, int audioSource = 7, int audioBitrate = 32, int audioSampleRate = 48000, RCCallAudioCodecType type = RCCallAudioCodecType.opus})
RCCallAudioConfig.fromJson(Map json)

Properties

audioBitrate ↔ int
getter/setter pair
audioSampleRate ↔ int
getter/setter pair
audioSource ↔ int
getter/setter pair
enableMicrophone ↔ bool
getter/setter pair
enableStereo ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ RCCallAudioCodecType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited