RCCallIOSPushConfig class

Constructors

RCCallIOSPushConfig.create({required String threadId, required String category, required String apnsCollapseId, required String richMediaUri})

Properties

apnsCollapseId → String
ZH
final
category → String
ZH
final
hashCode → int
The hash code for this object.
no setterinherited
richMediaUri → String
ZH
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadId → String
ZH
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited