RCCallPushConfig class

Constructors

RCCallPushConfig.create({String? templateId, String? title, String? content, String? data, bool disableTitle = false, bool forceShowDetailContent = false, RCCallIOSPushConfig? iOSConfig, RCCallAndroidPushConfig? androidConfig})

Properties

androidConfig ↔ RCCallAndroidPushConfig?
ZH
getter/setter pair
content ↔ String?
ZH
getter/setter pair
data ↔ String?
ZH
getter/setter pair
disableTitle ↔ bool
ZH
getter/setter pair
forceShowDetailContent ↔ bool
ZH
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iOSConfig ↔ RCCallIOSPushConfig?
ZH
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateId ↔ String?
ZH
getter/setter pair
title ↔ String?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited