RCCallVideoConfig class

Constructors

RCCallVideoConfig.create({RCCallVideoProfile profile = RCCallVideoProfile.profile_480_640_high, RCCallCamera defaultCamera = RCCallCamera.front, RCCallCameraOrientation cameraOrientation = RCCallCameraOrientation.portrait, bool enableHardwareDecoder = true, int hardwareDecoderColor = -1, bool enableHardwareEncoder = true, bool enableHardwareEncoderHighProfile = true, bool enableEncoderTexture = true, int hardWareEncoderColor = -1, int hardWareEncoderFrameRate = 30, RCCallVideoBitrateMode hardwareEncoderBitrateMode = RCCallVideoBitrateMode.cbr, bool previewMirror = true})
RCCallVideoConfig.fromJson(Map json)

Properties

cameraOrientation ↔ RCCallCameraOrientation
ZH
getter/setter pair
defaultCamera ↔ RCCallCamera
ZH
getter/setter pair
enableEncoderTexture ↔ bool
getter/setter pair
enableHardwareDecoder ↔ bool
ZH
getter/setter pair
enableHardwareEncoder ↔ bool
getter/setter pair
enableHardwareEncoderHighProfile ↔ bool
getter/setter pair
hardwareDecoderColor ↔ int
getter/setter pair
hardwareEncoderBitrateMode ↔ RCCallVideoBitrateMode
getter/setter pair
hardWareEncoderColor ↔ int
getter/setter pair
hardWareEncoderFrameRate ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
previewMirror ↔ bool
getter/setter pair
profile ↔ RCCallVideoProfile
ZH
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited